@@ -1,9 +1,9 @@
 library(phenofit)
 # simulate vegetation time-series
-fFUN = doubleLog.Beck
+FUN = doubleLog.Beck
 par  = c( mn  = 0.1, mx  = 0.7, sos = 50, rsp = 0.1, eos = 250, rau = 0.1)
 t    <- seq(1, 365, 8)
 tout <- seq(1, 365, 1)
-y <- fFUN(par, t)
+y <- FUN(par, t)
 methods <- c("AG", "Beck", "Elmore", "Gu", "Zhang") # "Klos" too slow
-fFITs <- curvefit(y, t, tout, methods)
+fit <- curvefit(y, t, tout, methods)
